# PyLoan

PyLoan can perform mortgage/loan calculations:

* Calculate payment amount to fully amortize a loan over its term.
* Amortize a loan based on the specified payment schedule.
* Consider ad-hoc or periodic special principal repayments during loan amortization schedule.
* Calculate interest payments using either 30/360 methods or actual methods.

All documentation is in the "docs" directory and online at https://pyloan.readthedocs.io/en/latest/.

## To-Do

* Add Actual method for interest rate compounding.
* Add loan summary details.
* Extend documentation.
